@@ -54,6 +54,16 @@ class FactDatasourceProxy(object):
         :return: list
         """
 
+    @abstractmethod
+    def collect_conditions(self, fd_code: str, size: int, condition_groups: list):
+        """
+        返回指定查询条件的数据
+        :param fd_code:
+        :param size: 返回的条数
+        :param condition_groups: 查询条件
+        :return: list
+        """
+
     @abstractmethod
     def query(self, fd_code: str, query: str, parameters: dict):
         """
@@ -184,6 +194,21 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         self._inner_field_permission(fd_context, result)
         return result
 
+    def collect_conditions(self, fd_code: str, size: int, condition_groups: list):
+        """
+        返回指定条数的数据
+        :param fd_code:
+        :param size: 返回的条数
+        :param condition_groups: 查询条件
+        :return: list
+        """
+        fd_context = self._get_fd_context(fd_code)
+        self._inner_check_permission(fd_context, 'read')
+        result = fd_context.collect_conditions(size, condition_groups)
+        # 这里需要对查询结果做字段过滤
+        self._inner_field_permission(fd_context, result)
+        return result
+
     def query(self, fd_code: str, query: str, parameters: dict):
         """
         使用查询语句查询数据
@@ -407,6 +432,35 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
+
+    def collect_conditions(self, fd_code: str, size: int, condition_groups: list):
+        """
+        返回指定条数的数据
+        :param fd_code:
+        :param size: 返回的条数
+        :param condition_groups: 查询条件
+        :return: list
+        """
+        check_instance_avaliable()
+
+        try:
+            r = do_service(f"/remote/fd-service/{fd_code}/conditions", method="post", data=condition_groups, params={'size': size})
+            if r is not None:
+                if isinstance(r, list):
+                    return [Munch(x) for x in r]
+                else:
+                    return Munch(r)
+            else:
+                return None
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 500:
+                # 说明服务器端报错了
+                raise ServiceInnerException(e.response._content.decode('utf-8'))
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
+                # 说明是认证相关的错误
+                raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
+            raise e
+
     def query(self, fd_code: str, query: str, parameters: dict):
         """
         对数据集进行查询
