@@ -151,4 +151,10 @@ def run_flask_with_celery():
     p2.start()
 
     p1.join()
-    p2.join()
\ No newline at end of file
+    p2.join()
+
+def run_with_auto_select():
+    if annotation.get_value("${celery.enable:false}"):
+        run_flask_with_celery()
+    else:
+        run_flask()
